summaryrefslogtreecommitdiff
path: root/src/smt
diff options
context:
space:
mode:
authormudathirmahgoub <mudathirmahgoub@gmail.com>2020-05-19 16:24:59 -0500
committerGitHub <noreply@github.com>2020-05-19 16:24:59 -0500
commitc8f149fa83fa16f821f37687fedfa778808809bd (patch)
tree8808ec522b58c0d8273280923b984a72e0b7bb29 /src/smt
parent6bb98062a5578d126db6a3e8cdca083881893b32 (diff)
Renamed operator CHOICE to WITNESS (#4207)
Renamed operator CHOICE to WITNESS, and removed it from the front end
Diffstat (limited to 'src/smt')
-rw-r--r--src/smt/term_formula_removal.cpp10
-rw-r--r--src/smt/term_formula_removal.h2
2 files changed, 6 insertions, 6 deletions
diff --git a/src/smt/term_formula_removal.h b/src/smt/term_formula_removal.h
index b6456bda6..3b72b46a5 100644
--- a/src/smt/term_formula_removal.h
+++ b/src/smt/term_formula_removal.h
@@ -112,7 +112,7 @@ public:
* This is sometimes called "lambda lifting"
*
* As an example of (4):
- * (choice x. P( x ) ) = t
+ * (witness x. P( x ) ) = t
* becomes
* P( k ) ^ k = t
* where k is a fresh skolem constant.
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback
diff --git a/src/smt/term_formula_removal.cpp b/src/smt/term_formula_removal.cpp
index d37ed05e1..1ae125e03 100644
--- a/src/smt/term_formula_removal.cpp
+++ b/src/smt/term_formula_removal.cpp
@@ -138,9 +138,9 @@ Node RemoveTermFormulas::run(TNode node, std::vector<Node>& output,
}
}
}
- else if (node.getKind() == kind::CHOICE)
+ else if (node.getKind() == kind::WITNESS)
{
- // If a Hilbert choice function, witness the choice.
+ // If a witness choice
// For details on this operator, see
// http://planetmath.org/hilbertsvarepsilonoperator.
if (!inQuant)
@@ -150,15 +150,15 @@ Node RemoveTermFormulas::run(TNode node, std::vector<Node>& output,
{
// Make the skolem to witness the choice
skolem = nodeManager->mkSkolem(
- "choiceK",
+ "witnessK",
nodeType,
- "a skolem introduced due to term-level Hilbert choice removal");
+ "a skolem introduced due to term-level witness removal");
d_skolem_cache.insert(node, skolem);
Assert(node[0].getNumChildren() == 1);
// The new assertion is the assumption that the body
// of the choice operator holds for the Skolem
newAssertion = node[1].substitute(node[0][0], skolem);
}
}
@@ -150,15 +150,15 @@ Node RemoveTermFormulas::run(TNode node, std::vector<Node>& output,
Assert(node[0].getNumChildren() == 1);
// The new assertion is the assumption that the body
- // of the choice operator holds for the Skolem
+ // of the witness operator holds for the Skolem
newAssertion = node[1].substitute(node[0][0], skolem);
}